summaryrefslogtreecommitdiff
path: root/src/libcamera/v4l2_device.cpp
diff options
context:
space:
mode:
authorJacopo Mondi <jacopo@jmondi.org>2019-01-21 17:53:28 +0100
committerJacopo Mondi <jacopo@jmondi.org>2019-01-22 14:14:04 +0100
commit1af83ca6df779fc3c7f8f4fc48f3ca82d824987d (patch)
tree7f5530f4ea838b04f23a07bb40c371c2f65e586a /src/libcamera/v4l2_device.cpp
parentd18d25bde3064a537d4b080488941fffd61e1739 (diff)
libcamera: Global s/devnode/deviceNode rename
Do not use the abreviated version for members, variables and getter methods. Library-wise rename, no intended functional changes. Reviewed-by: Niklas Söderlund <niklas.soderlund@ragnatech.se> Reviewed-by: Laurent Pinchart <laurent.pinchart@ideasonboard.com> Signed-off-by: Jacopo Mondi <jacopo@jmondi.org>
Diffstat (limited to 'src/libcamera/v4l2_device.cpp')
-rw-r--r--src/libcamera/v4l2_device.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/libcamera/v4l2_device.cpp b/src/libcamera/v4l2_device.cpp
index 5809fc62..2b17fa1e 100644
--- a/src/libcamera/v4l2_device.cpp
+++ b/src/libcamera/v4l2_device.cpp
@@ -88,10 +88,10 @@ LOG_DEFINE_CATEGORY(V4L2)
/**
* \brief Construct a V4L2Device
* \param devnode The file-system path to the video device node
*/
-V4L2Device::V4L2Device(const std::string &devnode)
- : devnode_(devnode), fd_(-1)
+V4L2Device::V4L2Device(const std::string &deviceNode)
+ : deviceNode_(deviceNode), fd_(-1)
{
}
@@ -102,7 +102,7 @@ V4L2Device::V4L2Device(const std::string &devnode)
* Construct a V4L2Device from a MediaEntity's device node path.
*/
V4L2Device::V4L2Device(const MediaEntity &entity)
- : V4L2Device(entity.devnode())
+ : V4L2Device(entity.deviceNode())
{
}
@@ -124,11 +124,11 @@ int V4L2Device::open()
return -EBUSY;
}
- ret = ::open(devnode_.c_str(), O_RDWR);
+ ret = ::open(deviceNode_.c_str(), O_RDWR);
if (ret < 0) {
ret = -errno;
LOG(V4L2, Error)
- << "Failed to open V4L2 device '" << devnode_
+ << "Failed to open V4L2 device '" << deviceNode_
<< "': " << strerror(-ret);
return ret;
}
@@ -144,7 +144,7 @@ int V4L2Device::open()
}
LOG(V4L2, Debug)
- << "Opened '" << devnode_ << "' "
+ << "Opened '" << deviceNode_ << "' "
<< caps_.bus_info() << ": " << caps_.driver()
<< ": " << caps_.card();
@@ -88,10 +88,10 @@ LOG_DEFINE_CATEGORY(V4L2)
/**
* \brief Construct a V4L2Device
- * \param devnode The file-system path to the video device node
+ * \param deviceNode The file-system path to the video device node
*/